@@ -13,7 +13,7 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(get sections);
 Readonly::Scalar my $EMPTY_STR => q{};
 
-our $VERSION = 0.13;
+our $VERSION = 0.14;
 
 # Get content for file or module.
 sub get {
@@ -93,7 +93,7 @@ sub _get_content {
 	# Remove spaces and return.
 	my $ret = _remove_spaces($child_pod);
 
-	return wantarray ? ($ret, $example_filename) : $ret;
+	return ($ret, $example_filename);
 }
 
 # Get section name.
@@ -306,12 +306,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2011-2022 Michal Josef Špaček
+© 2011-2023 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.13
+0.14
 
 =cut
